@@ -4,17 +4,15 @@ from typing import Any, Callable, TypeVar, Union
 __all__ = [
     "ADD_COMMENTS_REGEX_PATTERN",
     "ALL_NODE",
-    "ASTFunctionT",
     "DESCRIPTION",
     "EXCLUDE_REGEX_PATTERN",
-    "Function",
     "GLOB_PATTERN",
     "INCLUDE_REGEX_PATTERN",
     "SKIP_COMMENTS_REGEX_PATTERN",
     "VERSION",
 ]
 
-VERSION = "0.1.0"
+VERSION = "0.2.0"
 DESCRIPTION = (
     "Pyall is a linter that tries to keep "
     "the __all __ in your Python modules always up to date."
